SELECT 10/pyro-async - Criterion.rs

## SELECT 10/pyro-async

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0007473 | 0.0007759 | 0.0007467
Mean | 12.035 ms | 12.215 ms | 12.397 ms
Std. Dev. | 805.24 µs | 925.53 µs | 1.0352 ms
Median | 11.992 ms | 12.312 ms | 12.471 ms
MAD | 686.96 µs | 869.21 µs | 1.1726 ms

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.